from setuptools import setup

setup(name='arpit_probability_distribution_2020',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['arpit_probability_distribution_2020'],
      author = 'Arpit Maheshwari',
      author_email = 'arpitmaheshwari14@gmail.com',
      zip_safe=False)
